@@ -164,6 +164,10 @@ pub async fn deprovision(
 ) -> Result<(), Box<dyn Error>> {
     let instance_id = matches.value_of("instance").unwrap().to_string();
 
+    // the spec requires this parameters
+    let plan_id = matches.value_of("plan").unwrap_or("ignore").to_string();
+    let service_id = matches.value_of("service").unwrap_or("ignore").to_string();
+
     if options.curl_output {
         println!(
             "{}",
@@ -183,8 +187,8 @@ pub async fn deprovision(
         &config,
         DEFAULT_API_VERSION,
         &*instance_id,
-        "",
-        "",
+        &*plan_id,
+        &*service_id,
         Some(USER_AGENT),
         Some(!options.synchronous),
     )
@@ -369,7 +373,7 @@ pub async fn bind(
                     generate_curl_command(
                         "service_binding".to_owned(),
                         "GET".to_owned(),
-                        serde_json::to_string_pretty(&binding_request).unwrap(),
+                        "".to_owned(),
                         options.synchronous,
                         instance_id.clone(),
                         binding_id.clone(),
@@ -377,7 +381,10 @@ pub async fn bind(
                 );
             }
         }
+        return Ok(());
+    }
 
+    if !matches.is_present("binding") {
         let binding_response = service_binding_binding(
             &config,
             DEFAULT_API_VERSION,
